Import-Module ActiveDirectory
Import-Module MicrosoftTeams
# This script logs the results of the update operations to the console.
# If needed, you can redirect these to a log file (e.g.: `.\script.ps1 6> .\results.log`).
####### Set the following variables
$msTeamsUserName = 'jdoe@contoso.com'
$msTeamsPassword = 'YOUR_PASSWORD_HERE'
$adUserName = 'jdoe'
$adPassword = 'YOUR_PASSWORD_HERE'
$searchBase = 'OU=S8 Employee Accounts,DC=dev-stack8,DC=com'
#######
function Create-Credential {
    param (
        $UserName,
        $Password
    )
    $securePassword = ConvertTo-SecureString -String $Password -AsPlainText -Force
    return New-Object -TypeName System.Management.Automation.PSCredential -ArgumentList $UserName, $securePassword
}
$adCredential = Create-Credential -UserName $adUserName -Password $adPassword
$msTeamsCredential = Create-Credential -UserName $msTeamsUserName -Password $msTeamsPassword
Connect-MicrosoftTeams -Credential $msTeamsCredential
$voiceUsers = Get-CsOnlineUser -Filter {EnterpriseVoiceEnabled -eq $True} | Select UserPrincipalName, LineUri
foreach ( $voiceUser in $voiceUsers ) 
{
    $upn = $voiceUser.UserPrincipalName
    try
    {
        $adUserToUpdate = Get-ADUser -Credential $adCredential -Filter "userPrincipalName -eq '$upn'" -SearchBase $searchBase
        if ($null -eq $adUserToUpdate)
        {
            Write-Host "WARNING: Could not update user $upn - user does not exist in local AD" -ForegroundColor Yellow
            continue
        }
        $phoneNumber = $voiceUser.LineUri.replace('tel:', '').split(';ext=')[0]
        Set-ADUser -Credential $adCredential -Identity $adUserToUpdate.DistinguishedName -Replace @{telephoneNumber=$phoneNumber}
        Write-Host "Updated user $upn with phone number $phoneNumber"
    }
    catch
    {
        Write-Host "ERROR: Something went wrong when trying to update user $upn - $PSItem" -ForegroundColor Red
    }
}
